@@ -197,7 +197,7 @@ def display_code(value):
     Display input value as a code.
     """
     return format_html(
-        '<pre>{}</pre>',
+        '<pre style="max-height: 400px">{}</pre>',
         value
     ) if value else display_for_value(value)
 
